There are two main categories of data types in Verilog. These categories differ in the underlying hardware structure they represent, and they differ in the way they are assigned and retain values.
# Nets
A *net* refers to a *network* of connections that join two or more devices together.

Nets connect different hardware entities and *do not store values*. 
## Wire
A `wire` is the most commonly used type of net. When a port is declared in Verilog, it is implicitly given a type of `wire`.

It is illegal to re-declare a name already in use by a net:
```verilog
module foo;
	wire abc;
	wire a;
	wire b;
	wire c;

	wire abc; // ILLEGAL: The wire `abc` is already defined

```

# Variables
A variable is a data storage element. They retain the last input given.

## Registers
A `reg` can be used to model hardware registers because it stores a value until the next assignment.

### Integer
A Verilog `integer` type is a 32 bit wide storage value. It does not *need* to store integers, it can be used for other purposes.
```verilog
	integer   count;
```
### Time
A `time` variable is unsigned, 64 bits wide, and can be used to store time duration for debugging purposes. `realtime` is similar, but time is stored as a floating bit value.
# Scalar and Vector Types
